import cytoscape from"https://cdnjs.cloudflare.com/ajax/libs/cytoscape/3.17.1/cytoscape.esm.min.js";var SlipboxCollection_1=class{constructor(){this.cy=cytoscape({headless:!0})}addNote(e){const t=document.getElementById(e),r=t.querySelector("h1").textContent,n=t.getAttribute("data-filename");this.cy.add({data:{id:e,title:r,filename:n,label:r,bgColor:"gray"}})}addLink(e,t,r){const n=`${e}-${t}${r}`;this.cy.add({data:{id:n,source:e,target:t,tag:r}})}colorEntrypoints(){this.cy.nodes((e=>0===e.indegree(!1)&&e.outdegree(!1)>0)).data("bgColor","#4444aa")}};function graphArea(){const e=document.createElement("div");return e.innerHTML='\n    <div class="slipbox-graph-cytoscape"></div>\n    <div class="slipbox-graph-info">\n      <header>\n        <h3><a href=""></a></h3>\n        <p></p>\n      </header>\n    </div>\n  ',e}function clusterElements(e,t){const r=e.cy.edges(`[tag="${t}"]`);return r.connectedNodes().union(r.filter((e=>e.data("source")!==e.data("target"))))}function neighborElements(e,t){const r=e.cy.getElementById(t),n=new Set,i=r.incomers().edges("edge[tag]");for(;i.length>0;){const e=i.pop(),t=e.data("tag");n.has(e)||(i.push(...e.source().incomers(`edge[tag="${t}"]`)),n.add(e))}const s=new Set,o=r.outgoers().edges("edge[tag]");for(;o.length>0;){const e=o.pop(),t=e.data("tag");s.has(e)||(o.push(...e.target().outgoers(`edge[tag="${t}"]`)),s.add(e))}const a=e.cy.collection().union(Array.from(n)).union(Array.from(s)),l=a.connectedNodes(),u=r.openNeighborhood(),c=l.union(a).union(u).filter((e=>e.isNode()||e.data("source")!==e.data("target"))),d=c.getElementById(t).clone();return d.data("bgColor","black"),d.union(c)}function createCytoscape(e){const t=cytoscape({container:e.querySelector(".slipbox-graph-cytoscape"),selectionType:"additive",style:[{selector:"node",style:{label:"data(label)",height:"label",width:"label",padding:"8px",shape:"round-rectangle",color:"white","background-color":"data(bgColor)","text-halign":"center","text-valign":"center","text-wrap":"wrap","text-max-width":100}},{selector:"edge",style:{width:2,"curve-style":"bezier","line-color":"black","line-style":"solid","target-arrow-color":"black","target-arrow-shape":"triangle"}}]}),[r,n]=hoverHandlers(e);return t.on("select","node",r),t.on("unselect","node",n),t}function renderCytoscape(e,t="breadthfirst"){return"cose"===t?e.layout({name:"cose",nodeDimensionsIncludeLabels:!0,numIter:300,fit:!0}).run():e.layout({name:"breadthfirst",spacingFactor:1,fit:!0,directed:!0,avoidOverlap:!0,nodeDimensionsIncludeLabels:!0}).run(),e}function hoverHandlers(e){const t=e.querySelector(".slipbox-graph-info"),r=t.querySelector("header a"),n=t.querySelector("header p");return[e=>{const t=e.target.data("id");r.textContent=e.target.data("title"),r.href="#"+t,n.textContent=e.target.data("filename"),e.target.data("label",t)},e=>{r.textContent="",n.textContent="",e.target.data("label",e.target.data("title"))}]}var init=function(e){e.colorEntrypoints();const t=document.createElement("div");function r(){t.style.display="none";const r=window.location.hash.slice(1);let n=[],i="breadthfirst";if(r){const t=Number(r);if(Number.isInteger(t)){if(n=neighborElements(e,r),n.length<2)return}else n=clusterElements(e,r)}else n=e.cy.elements().filter((e=>e.isNode()||e.data("source")!==e.data("target"))),n.length>30&&(i="cose");if(0===n.length)return;t.style.display="block",t.innerHTML="";const s=createCytoscape(t.appendChild(graphArea()));s.add(n),renderCytoscape(s,i)}document.querySelector(".slipbox-bottom").appendChild(t),r(),window.addEventListener("hashchange",r)},graph={SlipboxCollection:SlipboxCollection_1,init:init},init$1=function(){const e=document.querySelectorAll("ol.slipbox-list > li[value]");for(let t=0;t<e.length;t++){const r=e[t],n=r.value,i=document.querySelector(`section.slipbox-note[id="${n}"]`);if(!i){r.remove();continue}const s=i.querySelector("h1");if(!s){r.remove();continue}const o=document.createElement("a");o.href=`#${n}`,o.innerHTML=s.innerHTML,r.appendChild(o)}},list={init:init$1};function createCommonjsModule(e){var t={exports:{}};return e(t,t.exports),t.exports
/**
 * lunr - http://lunrjs.com - A bit like Solr, but much smaller and not as bright - 2.3.9
 * Copyright (C) 2020 Oliver Nightingale
 * @license MIT
 */}var lunr=createCommonjsModule((function(e,t){!function(){var t,r,n,i,s,o,a,l,u,c,d,h,p,f,y,m,g,x,v,w,b,S,Q,E,k,L,T=function(e){var t=new T.Builder;return t.pipeline.add(T.trimmer,T.stopWordFilter,T.stemmer),t.searchPipeline.add(T.stemmer),e.call(t,t),t.build()};T.version="2.3.9",
/*!
 * lunr.utils
 * Copyright (C) 2020 Oliver Nightingale
 */
T.utils={},T.utils.warn=(t=this,function(e){t.console&&console.warn&&console.warn(e)}),T.utils.asString=function(e){return null==e?"":e.toString()},T.utils.clone=function(e){if(null==e)return e;for(var t=Object.create(null),r=Object.keys(e),n=0;n<r.length;n++){var i=r[n],s=e[i];if(Array.isArray(s))t[i]=s.slice();else{if("string"!=typeof s&&"number"!=typeof s&&"boolean"!=typeof s)throw new TypeError("clone is not deep and does not support nested objects");t[i]=s}}return t},T.FieldRef=function(e,t,r){this.docRef=e,this.fieldName=t,this._stringValue=r},T.FieldRef.joiner="/",T.FieldRef.fromString=function(e){var t=e.indexOf(T.FieldRef.joiner);if(-1===t)throw"malformed field ref string";var r=e.slice(0,t),n=e.slice(t+1);return new T.FieldRef(n,r,e)},T.FieldRef.prototype.toString=function(){return null==this._stringValue&&(this._stringValue=this.fieldName+T.FieldRef.joiner+this.docRef),this._stringValue},
/*!
 * lunr.Set
 * Copyright (C) 2020 Oliver Nightingale
 */
T.Set=function(e){if(this.elements=Object.create(null),e){this.length=e.length;for(var t=0;t<this.length;t++)this.elements[e[t]]=!0}else this.length=0},T.Set.complete={intersect:function(e){return e},union:function(){return this},contains:function(){return!0}},T.Set.empty={intersect:function(){return this},union:function(e){return e},contains:function(){return!1}},T.Set.prototype.contains=function(e){return!!this.elements[e]},T.Set.prototype.intersect=function(e){var t,r,n,i=[];if(e===T.Set.complete)return this;if(e===T.Set.empty)return e;this.length<e.length?(t=this,r=e):(t=e,r=this),n=Object.keys(t.elements);for(var s=0;s<n.length;s++){var o=n[s];o in r.elements&&i.push(o)}return new T.Set(i)},T.Set.prototype.union=function(e){return e===T.Set.complete?T.Set.complete:e===T.Set.empty?this:new T.Set(Object.keys(this.elements).concat(Object.keys(e.elements)))},T.idf=function(e,t){var r=0;for(var n in e)"_index"!=n&&(r+=Object.keys(e[n]).length);var i=(t-r+.5)/(r+.5);return Math.log(1+Math.abs(i))},T.Token=function(e,t){this.str=e||"",this.metadata=t||{}},T.Token.prototype.toString=function(){return this.str},T.Token.prototype.update=function(e){return this.str=e(this.str,this.metadata),this},T.Token.prototype.clone=function(e){return e=e||function(e){return e},new T.Token(e(this.str,this.metadata),this.metadata)},
/*!
 * lunr.tokenizer
 * Copyright (C) 2020 Oliver Nightingale
 */
T.tokenizer=function(e,t){if(null==e||null==e)return[];if(Array.isArray(e))return e.map((function(e){return new T.Token(T.utils.asString(e).toLowerCase(),T.utils.clone(t))}));for(var r=e.toString().toLowerCase(),n=r.length,i=[],s=0,o=0;s<=n;s++){var a=s-o;if(r.charAt(s).match(T.tokenizer.separator)||s==n){if(a>0){var l=T.utils.clone(t)||{};l.position=[o,a],l.index=i.length,i.push(new T.Token(r.slice(o,s),l))}o=s+1}}return i},T.tokenizer.separator=/[\s\-]+/,
/*!
 * lunr.Pipeline
 * Copyright (C) 2020 Oliver Nightingale
 */
T.Pipeline=function(){this._stack=[]},T.Pipeline.registeredFunctions=Object.create(null),T.Pipeline.registerFunction=function(e,t){t in this.registeredFunctions&&T.utils.warn("Overwriting existing registered function: "+t),e.label=t,T.Pipeline.registeredFunctions[e.label]=e},T.Pipeline.warnIfFunctionNotRegistered=function(e){e.label&&e.label in this.registeredFunctions||T.utils.warn("Function is not registered with pipeline. This may cause problems when serialising the index.\n",e)},T.Pipeline.load=function(e){var t=new T.Pipeline;return e.forEach((function(e){var r=T.Pipeline.registeredFunctions[e];if(!r)throw new Error("Cannot load unregistered function: "+e);t.add(r)})),t},T.Pipeline.prototype.add=function(){var e=Array.prototype.slice.call(arguments);e.forEach((function(e){T.Pipeline.warnIfFunctionNotRegistered(e),this._stack.push(e)}),this)},T.Pipeline.prototype.after=function(e,t){T.Pipeline.warnIfFunctionNotRegistered(t);var r=this._stack.indexOf(e);if(-1==r)throw new Error("Cannot find existingFn");r+=1,this._stack.splice(r,0,t)},T.Pipeline.prototype.before=function(e,t){T.Pipeline.warnIfFunctionNotRegistered(t);var r=this._stack.indexOf(e);if(-1==r)throw new Error("Cannot find existingFn");this._stack.splice(r,0,t)},T.Pipeline.prototype.remove=function(e){var t=this._stack.indexOf(e);-1!=t&&this._stack.splice(t,1)},T.Pipeline.prototype.run=function(e){for(var t=this._stack.length,r=0;r<t;r++){for(var n=this._stack[r],i=[],s=0;s<e.length;s++){var o=n(e[s],s,e);if(null!=o&&""!==o)if(Array.isArray(o))for(var a=0;a<o.length;a++)i.push(o[a]);else i.push(o)}e=i}return e},T.Pipeline.prototype.runString=function(e,t){var r=new T.Token(e,t);return this.run([r]).map((function(e){return e.toString()}))},T.Pipeline.prototype.reset=function(){this._stack=[]},T.Pipeline.prototype.toJSON=function(){return this._stack.map((function(e){return T.Pipeline.warnIfFunctionNotRegistered(e),e.label}))},
/*!
 * lunr.Vector
 * Copyright (C) 2020 Oliver Nightingale
 */
T.Vector=function(e){this._magnitude=0,this.elements=e||[]},T.Vector.prototype.positionForIndex=function(e){if(0==this.elements.length)return 0;for(var t=0,r=this.elements.length/2,n=r-t,i=Math.floor(n/2),s=this.elements[2*i];n>1&&(s<e&&(t=i),s>e&&(r=i),s!=e);)n=r-t,i=t+Math.floor(n/2),s=this.elements[2*i];return s==e||s>e?2*i:s<e?2*(i+1):void 0},T.Vector.prototype.insert=function(e,t){this.upsert(e,t,(function(){throw"duplicate index"}))},T.Vector.prototype.upsert=function(e,t,r){this._magnitude=0;var n=this.positionForIndex(e);this.elements[n]==e?this.elements[n+1]=r(this.elements[n+1],t):this.elements.splice(n,0,e,t)},T.Vector.prototype.magnitude=function(){if(this._magnitude)return this._magnitude;for(var e=0,t=this.elements.length,r=1;r<t;r+=2){var n=this.elements[r];e+=n*n}return this._magnitude=Math.sqrt(e)},T.Vector.prototype.dot=function(e){for(var t=0,r=this.elements,n=e.elements,i=r.length,s=n.length,o=0,a=0,l=0,u=0;l<i&&u<s;)(o=r[l])<(a=n[u])?l+=2:o>a?u+=2:o==a&&(t+=r[l+1]*n[u+1],l+=2,u+=2);return t},T.Vector.prototype.similarity=function(e){return this.dot(e)/this.magnitude()||0},T.Vector.prototype.toArray=function(){for(var e=new Array(this.elements.length/2),t=1,r=0;t<this.elements.length;t+=2,r++)e[r]=this.elements[t];return e},T.Vector.prototype.toJSON=function(){return this.elements},
/*!
 * lunr.stemmer
 * Copyright (C) 2020 Oliver Nightingale
 * Includes code from - http://tartarus.org/~martin/PorterStemmer/js.txt
 */
T.stemmer=(r={ational:"ate",tional:"tion",enci:"ence",anci:"ance",izer:"ize",bli:"ble",alli:"al",entli:"ent",eli:"e",ousli:"ous",ization:"ize",ation:"ate",ator:"ate",alism:"al",iveness:"ive",fulness:"ful",ousness:"ous",aliti:"al",iviti:"ive",biliti:"ble",logi:"log"},n={icate:"ic",ative:"",alize:"al",iciti:"ic",ical:"ic",ful:"",ness:""},i="[aeiouy]",s="[^aeiou][^aeiouy]*",o=new RegExp("^([^aeiou][^aeiouy]*)?[aeiouy][aeiou]*[^aeiou][^aeiouy]*"),a=new RegExp("^([^aeiou][^aeiouy]*)?[aeiouy][aeiou]*[^aeiou][^aeiouy]*[aeiouy][aeiou]*[^aeiou][^aeiouy]*"),l=new RegExp("^([^aeiou][^aeiouy]*)?[aeiouy][aeiou]*[^aeiou][^aeiouy]*([aeiouy][aeiou]*)?$"),u=new RegExp("^([^aeiou][^aeiouy]*)?[aeiouy]"),c=/^(.+?)(ss|i)es$/,d=/^(.+?)([^s])s$/,h=/^(.+?)eed$/,p=/^(.+?)(ed|ing)$/,f=/.$/,y=/(at|bl|iz)$/,m=new RegExp("([^aeiouylsz])\\1$"),g=new RegExp("^"+s+i+"[^aeiouwxy]$"),x=/^(.+?[^aeiou])y$/,v=/^(.+?)(ational|tional|enci|anci|izer|bli|alli|entli|eli|ousli|ization|ation|ator|alism|iveness|fulness|ousness|aliti|iviti|biliti|logi)$/,w=/^(.+?)(icate|ative|alize|iciti|ical|ful|ness)$/,b=/^(.+?)(al|ance|ence|er|ic|able|ible|ant|ement|ment|ent|ou|ism|ate|iti|ous|ive|ize)$/,S=/^(.+?)(s|t)(ion)$/,Q=/^(.+?)e$/,E=/ll$/,k=new RegExp("^"+s+i+"[^aeiouwxy]$"),L=function(e){var t,i,s,L,T,I,P;if(e.length<3)return e;if("y"==(s=e.substr(0,1))&&(e=s.toUpperCase()+e.substr(1)),T=d,(L=c).test(e)?e=e.replace(L,"$1$2"):T.test(e)&&(e=e.replace(T,"$1$2")),T=p,(L=h).test(e)){var R=L.exec(e);(L=o).test(R[1])&&(L=f,e=e.replace(L,""))}else T.test(e)&&(t=(R=T.exec(e))[1],(T=u).test(t)&&(I=m,P=g,(T=y).test(e=t)?e+="e":I.test(e)?(L=f,e=e.replace(L,"")):P.test(e)&&(e+="e")));return(L=x).test(e)&&(e=(t=(R=L.exec(e))[1])+"i"),(L=v).test(e)&&(t=(R=L.exec(e))[1],i=R[2],(L=o).test(t)&&(e=t+r[i])),(L=w).test(e)&&(t=(R=L.exec(e))[1],i=R[2],(L=o).test(t)&&(e=t+n[i])),T=S,(L=b).test(e)?(t=(R=L.exec(e))[1],(L=a).test(t)&&(e=t)):T.test(e)&&(t=(R=T.exec(e))[1]+R[2],(T=a).test(t)&&(e=t)),(L=Q).test(e)&&(t=(R=L.exec(e))[1],T=l,I=k,((L=a).test(t)||T.test(t)&&!I.test(t))&&(e=t)),T=a,(L=E).test(e)&&T.test(e)&&(L=f,e=e.replace(L,"")),"y"==s&&(e=s.toLowerCase()+e.substr(1)),e},function(e){return e.update(L)}),T.Pipeline.registerFunction(T.stemmer,"stemmer"),
/*!
 * lunr.stopWordFilter
 * Copyright (C) 2020 Oliver Nightingale
 */
T.generateStopWordFilter=function(e){var t=e.reduce((function(e,t){return e[t]=t,e}),{});return function(e){if(e&&t[e.toString()]!==e.toString())return e}},T.stopWordFilter=T.generateStopWordFilter(["a","able","about","across","after","all","almost","also","am","among","an","and","any","are","as","at","be","because","been","but","by","can","cannot","could","dear","did","do","does","either","else","ever","every","for","from","get","got","had","has","have","he","her","hers","him","his","how","however","i","if","in","into","is","it","its","just","least","let","like","likely","may","me","might","most","must","my","neither","no","nor","not","of","off","often","on","only","or","other","our","own","rather","said","say","says","she","should","since","so","some","than","that","the","their","them","then","there","these","they","this","tis","to","too","twas","us","wants","was","we","were","what","when","where","which","while","who","whom","why","will","with","would","yet","you","your"]),T.Pipeline.registerFunction(T.stopWordFilter,"stopWordFilter"),
/*!
 * lunr.trimmer
 * Copyright (C) 2020 Oliver Nightingale
 */
T.trimmer=function(e){return e.update((function(e){return e.replace(/^\W+/,"").replace(/\W+$/,"")}))},T.Pipeline.registerFunction(T.trimmer,"trimmer"),
/*!
 * lunr.TokenSet
 * Copyright (C) 2020 Oliver Nightingale
 */
T.TokenSet=function(){this.final=!1,this.edges={},this.id=T.TokenSet._nextId,T.TokenSet._nextId+=1},T.TokenSet._nextId=1,T.TokenSet.fromArray=function(e){for(var t=new T.TokenSet.Builder,r=0,n=e.length;r<n;r++)t.insert(e[r]);return t.finish(),t.root},T.TokenSet.fromClause=function(e){return"editDistance"in e?T.TokenSet.fromFuzzyString(e.term,e.editDistance):T.TokenSet.fromString(e.term)},T.TokenSet.fromFuzzyString=function(e,t){for(var r=new T.TokenSet,n=[{node:r,editsRemaining:t,str:e}];n.length;){var i=n.pop();if(i.str.length>0){var s,o=i.str.charAt(0);o in i.node.edges?s=i.node.edges[o]:(s=new T.TokenSet,i.node.edges[o]=s),1==i.str.length&&(s.final=!0),n.push({node:s,editsRemaining:i.editsRemaining,str:i.str.slice(1)})}if(0!=i.editsRemaining){if("*"in i.node.edges)var a=i.node.edges["*"];else{a=new T.TokenSet;i.node.edges["*"]=a}if(0==i.str.length&&(a.final=!0),n.push({node:a,editsRemaining:i.editsRemaining-1,str:i.str}),i.str.length>1&&n.push({node:i.node,editsRemaining:i.editsRemaining-1,str:i.str.slice(1)}),1==i.str.length&&(i.node.final=!0),i.str.length>=1){if("*"in i.node.edges)var l=i.node.edges["*"];else{l=new T.TokenSet;i.node.edges["*"]=l}1==i.str.length&&(l.final=!0),n.push({node:l,editsRemaining:i.editsRemaining-1,str:i.str.slice(1)})}if(i.str.length>1){var u,c=i.str.charAt(0),d=i.str.charAt(1);d in i.node.edges?u=i.node.edges[d]:(u=new T.TokenSet,i.node.edges[d]=u),1==i.str.length&&(u.final=!0),n.push({node:u,editsRemaining:i.editsRemaining-1,str:c+i.str.slice(2)})}}}return r},T.TokenSet.fromString=function(e){for(var t=new T.TokenSet,r=t,n=0,i=e.length;n<i;n++){var s=e[n],o=n==i-1;if("*"==s)t.edges[s]=t,t.final=o;else{var a=new T.TokenSet;a.final=o,t.edges[s]=a,t=a}}return r},T.TokenSet.prototype.toArray=function(){for(var e=[],t=[{prefix:"",node:this}];t.length;){var r=t.pop(),n=Object.keys(r.node.edges),i=n.length;r.node.final&&(r.prefix.charAt(0),e.push(r.prefix));for(var s=0;s<i;s++){var o=n[s];t.push({prefix:r.prefix.concat(o),node:r.node.edges[o]})}}return e},T.TokenSet.prototype.toString=function(){if(this._str)return this._str;for(var e=this.final?"1":"0",t=Object.keys(this.edges).sort(),r=t.length,n=0;n<r;n++){var i=t[n];e=e+i+this.edges[i].id}return e},T.TokenSet.prototype.intersect=function(e){for(var t=new T.TokenSet,r=void 0,n=[{qNode:e,output:t,node:this}];n.length;){r=n.pop();for(var i=Object.keys(r.qNode.edges),s=i.length,o=Object.keys(r.node.edges),a=o.length,l=0;l<s;l++)for(var u=i[l],c=0;c<a;c++){var d=o[c];if(d==u||"*"==u){var h=r.node.edges[d],p=r.qNode.edges[u],f=h.final&&p.final,y=void 0;d in r.output.edges?(y=r.output.edges[d]).final=y.final||f:((y=new T.TokenSet).final=f,r.output.edges[d]=y),n.push({qNode:p,output:y,node:h})}}}return t},T.TokenSet.Builder=function(){this.previousWord="",this.root=new T.TokenSet,this.uncheckedNodes=[],this.minimizedNodes={}},T.TokenSet.Builder.prototype.insert=function(e){var t,r=0;if(e<this.previousWord)throw new Error("Out of order word insertion");for(var n=0;n<e.length&&n<this.previousWord.length&&e[n]==this.previousWord[n];n++)r++;this.minimize(r),t=0==this.uncheckedNodes.length?this.root:this.uncheckedNodes[this.uncheckedNodes.length-1].child;for(n=r;n<e.length;n++){var i=new T.TokenSet,s=e[n];t.edges[s]=i,this.uncheckedNodes.push({parent:t,char:s,child:i}),t=i}t.final=!0,this.previousWord=e},T.TokenSet.Builder.prototype.finish=function(){this.minimize(0)},T.TokenSet.Builder.prototype.minimize=function(e){for(var t=this.uncheckedNodes.length-1;t>=e;t--){var r=this.uncheckedNodes[t],n=r.child.toString();n in this.minimizedNodes?r.parent.edges[r.char]=this.minimizedNodes[n]:(r.child._str=n,this.minimizedNodes[n]=r.child),this.uncheckedNodes.pop()}},
/*!
 * lunr.Index
 * Copyright (C) 2020 Oliver Nightingale
 */
T.Index=function(e){this.invertedIndex=e.invertedIndex,this.fieldVectors=e.fieldVectors,this.tokenSet=e.tokenSet,this.fields=e.fields,this.pipeline=e.pipeline},T.Index.prototype.search=function(e){return this.query((function(t){new T.QueryParser(e,t).parse()}))},T.Index.prototype.query=function(e){for(var t=new T.Query(this.fields),r=Object.create(null),n=Object.create(null),i=Object.create(null),s=Object.create(null),o=Object.create(null),a=0;a<this.fields.length;a++)n[this.fields[a]]=new T.Vector;e.call(t,t);for(a=0;a<t.clauses.length;a++){var l=t.clauses[a],u=null,c=T.Set.empty;u=l.usePipeline?this.pipeline.runString(l.term,{fields:l.fields}):[l.term];for(var d=0;d<u.length;d++){var h=u[d];l.term=h;var p=T.TokenSet.fromClause(l),f=this.tokenSet.intersect(p).toArray();if(0===f.length&&l.presence===T.Query.presence.REQUIRED){for(var y=0;y<l.fields.length;y++){s[O=l.fields[y]]=T.Set.empty}break}for(var m=0;m<f.length;m++){var g=f[m],x=this.invertedIndex[g],v=x._index;for(y=0;y<l.fields.length;y++){var w=x[O=l.fields[y]],b=Object.keys(w),S=g+"/"+O,Q=new T.Set(b);if(l.presence==T.Query.presence.REQUIRED&&(c=c.union(Q),void 0===s[O]&&(s[O]=T.Set.complete)),l.presence!=T.Query.presence.PROHIBITED){if(n[O].upsert(v,l.boost,(function(e,t){return e+t})),!i[S]){for(var E=0;E<b.length;E++){var k,L=b[E],I=new T.FieldRef(L,O),P=w[L];void 0===(k=r[I])?r[I]=new T.MatchData(g,O,P):k.add(g,O,P)}i[S]=!0}}else void 0===o[O]&&(o[O]=T.Set.empty),o[O]=o[O].union(Q)}}}if(l.presence===T.Query.presence.REQUIRED)for(y=0;y<l.fields.length;y++){s[O=l.fields[y]]=s[O].intersect(c)}}var R=T.Set.complete,C=T.Set.empty;for(a=0;a<this.fields.length;a++){var O;s[O=this.fields[a]]&&(R=R.intersect(s[O])),o[O]&&(C=C.union(o[O]))}var F=Object.keys(r),N=[],_=Object.create(null);if(t.isNegated()){F=Object.keys(this.fieldVectors);for(a=0;a<F.length;a++){I=F[a];var j=T.FieldRef.fromString(I);r[I]=new T.MatchData}}for(a=0;a<F.length;a++){var D=(j=T.FieldRef.fromString(F[a])).docRef;if(R.contains(D)&&!C.contains(D)){var A,$=this.fieldVectors[j],B=n[j.fieldName].similarity($);if(void 0!==(A=_[D]))A.score+=B,A.matchData.combine(r[j]);else{var M={ref:D,score:B,matchData:r[j]};_[D]=M,N.push(M)}}}return N.sort((function(e,t){return t.score-e.score}))},T.Index.prototype.toJSON=function(){var e=Object.keys(this.invertedIndex).sort().map((function(e){return[e,this.invertedIndex[e]]}),this),t=Object.keys(this.fieldVectors).map((function(e){return[e,this.fieldVectors[e].toJSON()]}),this);return{version:T.version,fields:this.fields,fieldVectors:t,invertedIndex:e,pipeline:this.pipeline.toJSON()}},T.Index.load=function(e){var t={},r={},n=e.fieldVectors,i=Object.create(null),s=e.invertedIndex,o=new T.TokenSet.Builder,a=T.Pipeline.load(e.pipeline);e.version!=T.version&&T.utils.warn("Version mismatch when loading serialised index. Current version of lunr '"+T.version+"' does not match serialized index '"+e.version+"'");for(var l=0;l<n.length;l++){var u=(d=n[l])[0],c=d[1];r[u]=new T.Vector(c)}for(l=0;l<s.length;l++){var d,h=(d=s[l])[0],p=d[1];o.insert(h),i[h]=p}return o.finish(),t.fields=e.fields,t.fieldVectors=r,t.invertedIndex=i,t.tokenSet=o.root,t.pipeline=a,new T.Index(t)},
/*!
 * lunr.Builder
 * Copyright (C) 2020 Oliver Nightingale
 */
T.Builder=function(){this._ref="id",this._fields=Object.create(null),this._documents=Object.create(null),this.invertedIndex=Object.create(null),this.fieldTermFrequencies={},this.fieldLengths={},this.tokenizer=T.tokenizer,this.pipeline=new T.Pipeline,this.searchPipeline=new T.Pipeline,this.documentCount=0,this._b=.75,this._k1=1.2,this.termIndex=0,this.metadataWhitelist=[]},T.Builder.prototype.ref=function(e){this._ref=e},T.Builder.prototype.field=function(e,t){if(/\//.test(e))throw new RangeError("Field '"+e+"' contains illegal character '/'");this._fields[e]=t||{}},T.Builder.prototype.b=function(e){this._b=e<0?0:e>1?1:e},T.Builder.prototype.k1=function(e){this._k1=e},T.Builder.prototype.add=function(e,t){var r=e[this._ref],n=Object.keys(this._fields);this._documents[r]=t||{},this.documentCount+=1;for(var i=0;i<n.length;i++){var s=n[i],o=this._fields[s].extractor,a=o?o(e):e[s],l=this.tokenizer(a,{fields:[s]}),u=this.pipeline.run(l),c=new T.FieldRef(r,s),d=Object.create(null);this.fieldTermFrequencies[c]=d,this.fieldLengths[c]=0,this.fieldLengths[c]+=u.length;for(var h=0;h<u.length;h++){var p=u[h];if(null==d[p]&&(d[p]=0),d[p]+=1,null==this.invertedIndex[p]){var f=Object.create(null);f._index=this.termIndex,this.termIndex+=1;for(var y=0;y<n.length;y++)f[n[y]]=Object.create(null);this.invertedIndex[p]=f}null==this.invertedIndex[p][s][r]&&(this.invertedIndex[p][s][r]=Object.create(null));for(var m=0;m<this.metadataWhitelist.length;m++){var g=this.metadataWhitelist[m],x=p.metadata[g];null==this.invertedIndex[p][s][r][g]&&(this.invertedIndex[p][s][r][g]=[]),this.invertedIndex[p][s][r][g].push(x)}}}},T.Builder.prototype.calculateAverageFieldLengths=function(){for(var e=Object.keys(this.fieldLengths),t=e.length,r={},n={},i=0;i<t;i++){var s=T.FieldRef.fromString(e[i]),o=s.fieldName;n[o]||(n[o]=0),n[o]+=1,r[o]||(r[o]=0),r[o]+=this.fieldLengths[s]}var a=Object.keys(this._fields);for(i=0;i<a.length;i++){var l=a[i];r[l]=r[l]/n[l]}this.averageFieldLength=r},T.Builder.prototype.createFieldVectors=function(){for(var e={},t=Object.keys(this.fieldTermFrequencies),r=t.length,n=Object.create(null),i=0;i<r;i++){for(var s=T.FieldRef.fromString(t[i]),o=s.fieldName,a=this.fieldLengths[s],l=new T.Vector,u=this.fieldTermFrequencies[s],c=Object.keys(u),d=c.length,h=this._fields[o].boost||1,p=this._documents[s.docRef].boost||1,f=0;f<d;f++){var y,m,g,x=c[f],v=u[x],w=this.invertedIndex[x]._index;void 0===n[x]?(y=T.idf(this.invertedIndex[x],this.documentCount),n[x]=y):y=n[x],m=y*((this._k1+1)*v)/(this._k1*(1-this._b+this._b*(a/this.averageFieldLength[o]))+v),m*=h,m*=p,g=Math.round(1e3*m)/1e3,l.insert(w,g)}e[s]=l}this.fieldVectors=e},T.Builder.prototype.createTokenSet=function(){this.tokenSet=T.TokenSet.fromArray(Object.keys(this.invertedIndex).sort())},T.Builder.prototype.build=function(){return this.calculateAverageFieldLengths(),this.createFieldVectors(),this.createTokenSet(),new T.Index({invertedIndex:this.invertedIndex,fieldVectors:this.fieldVectors,tokenSet:this.tokenSet,fields:Object.keys(this._fields),pipeline:this.searchPipeline})},T.Builder.prototype.use=function(e){var t=Array.prototype.slice.call(arguments,1);t.unshift(this),e.apply(this,t)},T.MatchData=function(e,t,r){for(var n=Object.create(null),i=Object.keys(r||{}),s=0;s<i.length;s++){var o=i[s];n[o]=r[o].slice()}this.metadata=Object.create(null),void 0!==e&&(this.metadata[e]=Object.create(null),this.metadata[e][t]=n)},T.MatchData.prototype.combine=function(e){for(var t=Object.keys(e.metadata),r=0;r<t.length;r++){var n=t[r],i=Object.keys(e.metadata[n]);null==this.metadata[n]&&(this.metadata[n]=Object.create(null));for(var s=0;s<i.length;s++){var o=i[s],a=Object.keys(e.metadata[n][o]);null==this.metadata[n][o]&&(this.metadata[n][o]=Object.create(null));for(var l=0;l<a.length;l++){var u=a[l];null==this.metadata[n][o][u]?this.metadata[n][o][u]=e.metadata[n][o][u]:this.metadata[n][o][u]=this.metadata[n][o][u].concat(e.metadata[n][o][u])}}}},T.MatchData.prototype.add=function(e,t,r){if(!(e in this.metadata))return this.metadata[e]=Object.create(null),void(this.metadata[e][t]=r);if(t in this.metadata[e])for(var n=Object.keys(r),i=0;i<n.length;i++){var s=n[i];s in this.metadata[e][t]?this.metadata[e][t][s]=this.metadata[e][t][s].concat(r[s]):this.metadata[e][t][s]=r[s]}else this.metadata[e][t]=r},T.Query=function(e){this.clauses=[],this.allFields=e},T.Query.wildcard=new String("*"),T.Query.wildcard.NONE=0,T.Query.wildcard.LEADING=1,T.Query.wildcard.TRAILING=2,T.Query.presence={OPTIONAL:1,REQUIRED:2,PROHIBITED:3},T.Query.prototype.clause=function(e){return"fields"in e||(e.fields=this.allFields),"boost"in e||(e.boost=1),"usePipeline"in e||(e.usePipeline=!0),"wildcard"in e||(e.wildcard=T.Query.wildcard.NONE),e.wildcard&T.Query.wildcard.LEADING&&e.term.charAt(0)!=T.Query.wildcard&&(e.term="*"+e.term),e.wildcard&T.Query.wildcard.TRAILING&&e.term.slice(-1)!=T.Query.wildcard&&(e.term=e.term+"*"),"presence"in e||(e.presence=T.Query.presence.OPTIONAL),this.clauses.push(e),this},T.Query.prototype.isNegated=function(){for(var e=0;e<this.clauses.length;e++)if(this.clauses[e].presence!=T.Query.presence.PROHIBITED)return!1;return!0},T.Query.prototype.term=function(e,t){if(Array.isArray(e))return e.forEach((function(e){this.term(e,T.utils.clone(t))}),this),this;var r=t||{};return r.term=e.toString(),this.clause(r),this},T.QueryParseError=function(e,t,r){this.name="QueryParseError",this.message=e,this.start=t,this.end=r},T.QueryParseError.prototype=new Error,T.QueryLexer=function(e){this.lexemes=[],this.str=e,this.length=e.length,this.pos=0,this.start=0,this.escapeCharPositions=[]},T.QueryLexer.prototype.run=function(){for(var e=T.QueryLexer.lexText;e;)e=e(this)},T.QueryLexer.prototype.sliceString=function(){for(var e=[],t=this.start,r=this.pos,n=0;n<this.escapeCharPositions.length;n++)r=this.escapeCharPositions[n],e.push(this.str.slice(t,r)),t=r+1;return e.push(this.str.slice(t,this.pos)),this.escapeCharPositions.length=0,e.join("")},T.QueryLexer.prototype.emit=function(e){this.lexemes.push({type:e,str:this.sliceString(),start:this.start,end:this.pos}),this.start=this.pos},T.QueryLexer.prototype.escapeCharacter=function(){this.escapeCharPositions.push(this.pos-1),this.pos+=1},T.QueryLexer.prototype.next=function(){if(this.pos>=this.length)return T.QueryLexer.EOS;var e=this.str.charAt(this.pos);return this.pos+=1,e},T.QueryLexer.prototype.width=function(){return this.pos-this.start},T.QueryLexer.prototype.ignore=function(){this.start==this.pos&&(this.pos+=1),this.start=this.pos},T.QueryLexer.prototype.backup=function(){this.pos-=1},T.QueryLexer.prototype.acceptDigitRun=function(){var e,t;do{t=(e=this.next()).charCodeAt(0)}while(t>47&&t<58);e!=T.QueryLexer.EOS&&this.backup()},T.QueryLexer.prototype.more=function(){return this.pos<this.length},T.QueryLexer.EOS="EOS",T.QueryLexer.FIELD="FIELD",T.QueryLexer.TERM="TERM",T.QueryLexer.EDIT_DISTANCE="EDIT_DISTANCE",T.QueryLexer.BOOST="BOOST",T.QueryLexer.PRESENCE="PRESENCE",T.QueryLexer.lexField=function(e){return e.backup(),e.emit(T.QueryLexer.FIELD),e.ignore(),T.QueryLexer.lexText},T.QueryLexer.lexTerm=function(e){if(e.width()>1&&(e.backup(),e.emit(T.QueryLexer.TERM)),e.ignore(),e.more())return T.QueryLexer.lexText},T.QueryLexer.lexEditDistance=function(e){return e.ignore(),e.acceptDigitRun(),e.emit(T.QueryLexer.EDIT_DISTANCE),T.QueryLexer.lexText},T.QueryLexer.lexBoost=function(e){return e.ignore(),e.acceptDigitRun(),e.emit(T.QueryLexer.BOOST),T.QueryLexer.lexText},T.QueryLexer.lexEOS=function(e){e.width()>0&&e.emit(T.QueryLexer.TERM)},T.QueryLexer.termSeparator=T.tokenizer.separator,T.QueryLexer.lexText=function(e){for(;;){var t=e.next();if(t==T.QueryLexer.EOS)return T.QueryLexer.lexEOS;if(92!=t.charCodeAt(0)){if(":"==t)return T.QueryLexer.lexField;if("~"==t)return e.backup(),e.width()>0&&e.emit(T.QueryLexer.TERM),T.QueryLexer.lexEditDistance;if("^"==t)return e.backup(),e.width()>0&&e.emit(T.QueryLexer.TERM),T.QueryLexer.lexBoost;if("+"==t&&1===e.width())return e.emit(T.QueryLexer.PRESENCE),T.QueryLexer.lexText;if("-"==t&&1===e.width())return e.emit(T.QueryLexer.PRESENCE),T.QueryLexer.lexText;if(t.match(T.QueryLexer.termSeparator))return T.QueryLexer.lexTerm}else e.escapeCharacter()}},T.QueryParser=function(e,t){this.lexer=new T.QueryLexer(e),this.query=t,this.currentClause={},this.lexemeIdx=0},T.QueryParser.prototype.parse=function(){this.lexer.run(),this.lexemes=this.lexer.lexemes;for(var e=T.QueryParser.parseClause;e;)e=e(this);return this.query},T.QueryParser.prototype.peekLexeme=function(){return this.lexemes[this.lexemeIdx]},T.QueryParser.prototype.consumeLexeme=function(){var e=this.peekLexeme();return this.lexemeIdx+=1,e},T.QueryParser.prototype.nextClause=function(){var e=this.currentClause;this.query.clause(e),this.currentClause={}},T.QueryParser.parseClause=function(e){var t=e.peekLexeme();if(null!=t)switch(t.type){case T.QueryLexer.PRESENCE:return T.QueryParser.parsePresence;case T.QueryLexer.FIELD:return T.QueryParser.parseField;case T.QueryLexer.TERM:return T.QueryParser.parseTerm;default:var r="expected either a field or a term, found "+t.type;throw t.str.length>=1&&(r+=" with value '"+t.str+"'"),new T.QueryParseError(r,t.start,t.end)}},T.QueryParser.parsePresence=function(e){var t=e.consumeLexeme();if(null!=t){switch(t.str){case"-":e.currentClause.presence=T.Query.presence.PROHIBITED;break;case"+":e.currentClause.presence=T.Query.presence.REQUIRED;break;default:var r="unrecognised presence operator'"+t.str+"'";throw new T.QueryParseError(r,t.start,t.end)}var n=e.peekLexeme();if(null==n){r="expecting term or field, found nothing";throw new T.QueryParseError(r,t.start,t.end)}switch(n.type){case T.QueryLexer.FIELD:return T.QueryParser.parseField;case T.QueryLexer.TERM:return T.QueryParser.parseTerm;default:r="expecting term or field, found '"+n.type+"'";throw new T.QueryParseError(r,n.start,n.end)}}},T.QueryParser.parseField=function(e){var t=e.consumeLexeme();if(null!=t){if(-1==e.query.allFields.indexOf(t.str)){var r=e.query.allFields.map((function(e){return"'"+e+"'"})).join(", "),n="unrecognised field '"+t.str+"', possible fields: "+r;throw new T.QueryParseError(n,t.start,t.end)}e.currentClause.fields=[t.str];var i=e.peekLexeme();if(null==i){n="expecting term, found nothing";throw new T.QueryParseError(n,t.start,t.end)}switch(i.type){case T.QueryLexer.TERM:return T.QueryParser.parseTerm;default:n="expecting term, found '"+i.type+"'";throw new T.QueryParseError(n,i.start,i.end)}}},T.QueryParser.parseTerm=function(e){var t=e.consumeLexeme();if(null!=t){e.currentClause.term=t.str.toLowerCase(),-1!=t.str.indexOf("*")&&(e.currentClause.usePipeline=!1);var r=e.peekLexeme();if(null!=r)switch(r.type){case T.QueryLexer.TERM:return e.nextClause(),T.QueryParser.parseTerm;case T.QueryLexer.FIELD:return e.nextClause(),T.QueryParser.parseField;case T.QueryLexer.EDIT_DISTANCE:return T.QueryParser.parseEditDistance;case T.QueryLexer.BOOST:return T.QueryParser.parseBoost;case T.QueryLexer.PRESENCE:return e.nextClause(),T.QueryParser.parsePresence;default:var n="Unexpected lexeme type '"+r.type+"'";throw new T.QueryParseError(n,r.start,r.end)}else e.nextClause()}},T.QueryParser.parseEditDistance=function(e){var t=e.consumeLexeme();if(null!=t){var r=parseInt(t.str,10);if(isNaN(r)){var n="edit distance must be numeric";throw new T.QueryParseError(n,t.start,t.end)}e.currentClause.editDistance=r;var i=e.peekLexeme();if(null!=i)switch(i.type){case T.QueryLexer.TERM:return e.nextClause(),T.QueryParser.parseTerm;case T.QueryLexer.FIELD:return e.nextClause(),T.QueryParser.parseField;case T.QueryLexer.EDIT_DISTANCE:return T.QueryParser.parseEditDistance;case T.QueryLexer.BOOST:return T.QueryParser.parseBoost;case T.QueryLexer.PRESENCE:return e.nextClause(),T.QueryParser.parsePresence;default:n="Unexpected lexeme type '"+i.type+"'";throw new T.QueryParseError(n,i.start,i.end)}else e.nextClause()}},T.QueryParser.parseBoost=function(e){var t=e.consumeLexeme();if(null!=t){var r=parseInt(t.str,10);if(isNaN(r)){var n="boost must be numeric";throw new T.QueryParseError(n,t.start,t.end)}e.currentClause.boost=r;var i=e.peekLexeme();if(null!=i)switch(i.type){case T.QueryLexer.TERM:return e.nextClause(),T.QueryParser.parseTerm;case T.QueryLexer.FIELD:return e.nextClause(),T.QueryParser.parseField;case T.QueryLexer.EDIT_DISTANCE:return T.QueryParser.parseEditDistance;case T.QueryLexer.BOOST:return T.QueryParser.parseBoost;case T.QueryLexer.PRESENCE:return e.nextClause(),T.QueryParser.parsePresence;default:n="Unexpected lexeme type '"+i.type+"'";throw new T.QueryParseError(n,i.start,i.end)}else e.nextClause()}},e.exports=T}()}));function extractTitle(e){const t=e?.querySelector("h1")?.textContent,r=document.createElement("h3");return r.innerHTML=`<a href="#${e.id}">${t}</a>`,t?r:null}function extractSummary(e){const t=extractTitle(e);if(!t)return null;const r=document.createDocumentFragment();r.appendChild(t);const n=t.textContent;let i=3;for(const t of e.children){if(i--<=0)break;const e=t.cloneNode(!0);"H1"===e.tagName&&e.textContent===n||r.appendChild(e)}return r}function createResultFromSection(e){const t=extractSummary(e);if(!t)return null;const r=document.createElement("div");return r.classList.add("search-result"),r.appendChild(t),r}class Search{constructor(e,t=null){this.index=lunr((function(){this.ref("id"),this.field("textContent"),e.forEach((function(e){this.add(e)}),this)}))}render(e){e.input.addEventListener("change",(()=>{window.location.hash="#search";const t=this.index.search(e.input.value);e.results.textContent="";for(const r of t){const t=createResultFromSection(document.getElementById(r.ref));t&&e.results.appendChild(t),e.results.appendChild(document.createElement("hr"))}}))}}var init$2=function(){const e=Array.from(document.getElementsByClassName("slipbox-note"));new Search(e).render({results:document.querySelector("#search > .search-results"),input:document.querySelector('nav input[type="text"]')})},search={init:init$2};function getScore(e){return Number(window.localStorage.getItem(`${e}.score`))}function setScore(e,t){window.localStorage.setItem(`${e}.score`,t)}function getTotal(e){return Number(window.localStorage.getItem(`${e}.total`))}function setTotal(e,t){window.localStorage.setItem(`${e}.total`,t)}function getRecent(e){return window.localStorage.getItem(`${e}.recent`)}function popRecent(e){const t=getRecent(e)||"";window.localStorage.setItem(`${e}.recent`,t.slice(0,t.length-1))}function pushRecent(e,t){const r=window.localStorage.getItem(`${e}.recent`);window.localStorage.setItem(`${e}.recent`,r+(t?"1":"0"))}function shuffle(e){for(let t=e.length-1;t>0;t--){const r=Math.floor(Math.random()*(t+1)),n=e[t];e[t]=e[r],e[r]=n}}var Flashcard_1=class{constructor(e){this.pressed=null,this.container=e,window.addEventListener("hashchange",(()=>{this.pressed=null,this.render()}))}pressUp(e){const t=getScore(e),r=getTotal(e);switch(this.pressed){case"up":this.pressed=null,setScore(e,t-1),setTotal(e,r-1),popRecent(e);break;case"down":this.pressed="up",setScore(e,t+1),popRecent(e),pushRecent(e,!0);break;default:this.pressed="up",setScore(e,t+1),setTotal(e,r+1),pushRecent(e,!0)}this.render()}pressDown(e){const t=getScore(e),r=getTotal(e);switch(this.pressed){case"up":this.pressed="down",setScore(e,t-1),popRecent(e),pushRecent(e,!1);break;case"down":this.pressed=null,setTotal(e,r-1),popRecent(e);break;default:this.pressed="down",setTotal(e,r+1),pushRecent(e,!1)}this.render()}render(){this.container.classList.add("slipbox-srs"),this.container.innerHTML="";const e=window.location.hash.slice(1);if(!e||!Number.isInteger(Number(e)))return;this.container.innerHTML=`\n      <button class="slipbox-srs-down">▼</button>\n      <span class="slipbox-srs-score">${getScore(e)}</span>\n      out of\n      <span class="slipbox-srs-total">${getTotal(e)}</span>\n      <button class="slipbox-srs-up">▲</button>\n    `;const t=this.container.querySelector(".slipbox-srs-down"),r=this.container.querySelector(".slipbox-srs-up"),n=this.container.querySelector(".slipbox-srs-score"),i=this.container.querySelector(".slipbox-srs-total");switch(r.addEventListener("click",(()=>this.pressUp(e))),t.addEventListener("click",(()=>this.pressDown(e))),this.pressed){case"up":r.classList.add("slipbox-srs-pressed"),t.classList.remove("slipbox-srs-pressed");break;case"down":r.classList.remove("slipbox-srs-pressed"),t.classList.add("slipbox-srs-pressed");break;default:r.classList.remove("slipbox-srs-pressed"),t.classList.remove("slipbox-srs-pressed")}n.textContent=getScore(e),i.textContent=getTotal(e)}},Scheduler_1=class{constructor(e,t){this.sched=[],this.ids=t,this.container=e}isReady(e){let t=getRecent(e)||"";t.length>8&&(t=t.slice(t.length-8,t.length));const r=Array.from(t).reduce(((e,t)=>"0"===t?e:e+1),0);return window.localStorage.setItem(`${e}.recent`,t),Math.random()<=2**-r}schedule(){if(this.sched.length>0)return this;shuffle(this.ids);for(const e of this.ids)this.isReady(e)&&this.sched.push(e);return this}render(){this.container.addEventListener("click",(()=>{this.container.href="#"+this.next()}))}next(){for(;0===this.sched.length;)this.schedule();return this.sched.pop()}},_getRecent=getRecent,srs={Flashcard:Flashcard_1,Scheduler:Scheduler_1,_getRecent:_getRecent};function initSRS(e){const t=document.createElement("div");document.querySelector(".slipbox-bottom").appendChild(t),new srs.Flashcard(t).render(),new srs.Scheduler(document.querySelector('nav a[href="#random"]'),e.cy.nodes().map((e=>e.data("id")))).render()}window.slipbox=new graph.SlipboxCollection,window.initSlipbox=function(){const e=document.getElementById("title-block-header");e&&e.remove(),list.init(),search.init(),initSRS(window.slipbox),graph.init(window.slipbox)};var src={};export default src;